yakumo.exception

Package yakumo :: Module exception |
[hide private]
[frames] | no frames]

# Source Code for Module yakumo.exception

     1  # Copyright 2014-2017 by Akira Yoshiyama <akirayoshiyama@gmail.com>.
     2  # All Rights Reserved.
     3  #
     4  #   Licensed under the Apache License, Version 2.0 (the "License"); you may
     5  #   not use this file except in compliance with the License. You may obtain
     6  #   a copy of the License at
     7  #
     8  #       http://www.apache.org/licenses/LICENSE-2.0
     9  #
    10  #   Unless required by applicable law or agreed to in writing, software
    11  #   distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
    12  #   WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
    13  #   License for the specific language governing permissions and limitations
    14  #   under the License.
    15
    16  """
    17  Exception classes
    18  """
    19
    20  from requests.exceptions import HTTPError
    21
    22
    23 -class BadRequest(Exception):
    24      """400 Bad Request"""
    25
    26
    27 -class Unauthorized(Exception):
    28      """401 Unauthorized"""
    29
    30
    31 -class PaymentRequired(Exception):
    32      """402 Payment Required"""
    33
    34
    35 -class Forbidden(Exception):
    36      """403 Forbidden"""
    37
    38
    39 -class NotFound(Exception):
    40      """404 NotFound"""
    41
    42
    43 -class NoSuchAPI(Exception):
    44      pass
    45
    46
    47  mapping = {
    48      400: BadRequest,
    49      401: Unauthorized,
    50      402: PaymentRequired,
    51      403: Forbidden,
    52      404: NotFound
    53  }
    54